@@ -5,6 +5,7 @@
 from __future__ import division
 import numpy as np
 import scipy.integrate as si
+from .tools import find_intersections
 from ..package_tools import Exporter
 from ..constants import epsilon, kappa, P0, Rd, Lv, Cp_d
 from ..units import atleast_1d, concatenate, units
@@ -52,7 +53,7 @@ def potential_temperature(pressure, temperature):
 
     '''
 
-    return temperature * (P0 / pressure)**kappa
+    return temperature * (P0 / pressure).to('dimensionless')**kappa
 
 
 @exporter.export
@@ -135,7 +136,7 @@ def moist_lapse(pressure, temperature):
     def dt(t, p):
         t = units.Quantity(t, temperature.units)
         p = units.Quantity(p, pressure.units)
-        rs = mixing_ratio(saturation_vapor_pressure(t), p)
+        rs = saturation_mixing_ratio(p, t)
         frac = ((Rd * t + Lv * rs) /
                 (Cp_d + (Lv * Lv * rs * epsilon / (Rd * t * t)))).to('kelvin')
         return frac / p
@@ -200,6 +201,36 @@ def lcl(pressure, temperature, dewpt, max_iters=50, eps=1e-2):
     return new_p
 
 
+@exporter.export
+def lfc(pressure, temperature, dewpt):
+    r'''Calculate the level of free convection (LFC) by finding the first
+    intersection of the ideal parcel path and the measured parcel
+    temperature.
+
+    Parameters
+    ----------
+    pressure : array_like
+        The starting atmospheric pressure
+    temperature : array_like
+        The starting temperature
+    dewpt : array_like
+        The starting dew point
+
+    Returns
+    -------
+    array_like
+        The LFC
+
+    See Also
+    --------
+    parcel_profile
+    '''
+
+    ideal_profile = parcel_profile(pressure, temperature[0], dewpt[0]).to('degC')
+    intersections = find_intersections(pressure, ideal_profile, temperature)
+    return intersections[0]
+
+
 @exporter.export
 def parcel_profile(pressure, temperature, dewpt):
     r'''Calculate the profile a parcel takes through the atmosphere, lifting
@@ -398,3 +429,65 @@ def mixing_ratio(part_press, tot_press):
     '''
 
     return epsilon * part_press / (tot_press - part_press)
+
+
+@exporter.export
+def saturation_mixing_ratio(tot_press, temperature):
+    r'''Calculates the saturation mixing ratio given total pressure
+    and the temperature.
+
+    The implementation uses the formula outlined in [4]
+
+    Parameters
+    ----------
+    tot_press: array_like
+        Total atmospheric pressure
+    temperature: array_like
+        The temperature
+
+    Returns
+    -------
+    array_like
+        The saturation mixing ratio, dimensionless
+
+    References
+    ----------
+    .. [4] Hobbs, Peter V. and Wallace, John M., 1977: Atmospheric Science, an Introductory
+            Survey. 73.
+    '''
+
+    return mixing_ratio(saturation_vapor_pressure(temperature), tot_press)
+
+
+@exporter.export
+def equivalent_potential_temperature(pressure, temperature):
+    r'''Calculates equivalent potential temperature given an air parcel's
+    pressure and temperature.
+
+    The implementation uses the formula outlined in [5]
+
+    Parameters
+    ----------
+    pressure: array_like
+        Total atmospheric pressure
+    temperature: array_like
+        The temperature
+
+    Returns
+    -------
+    array_like
+        The corresponding equivalent potential temperature of the parcel
+
+    Notes
+    -----
+    .. math:: \Theta_e = \Theta e^\frac{L_v r_s}{C_{pd} T}
+
+    References
+    ----------
+    .. [5] Hobbs, Peter V. and Wallace, John M., 1977: Atmospheric Science, an Introductory
+            Survey. 78-79.
+    '''
+
+    pottemp = potential_temperature(pressure, temperature)
+    smixr = saturation_mixing_ratio(pressure, temperature)
+    return pottemp * np.exp(Lv * smixr / (Cp_d * temperature))
